﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Steema.TeeChart;
using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TeeChart.WinForm.TEST
{
    public partial class Form1 : Form
    {
        string _projectPath = Application.StartupPath;

        public Form1()
        {
            InitializeComponent();

            LoadData();

            tChart1.Export.Template.SaveAsync("template.json");
            tChart1.Import.Template.LoadAsync("template.json");

            CreateFunction();
        }

        private void CreateFunction()
        {
            tChart1.Series[1].DataSource = new object[] { tChart1.Series[0] };
            tChart1.Series[1].Function = new Average
            {
                PeriodStyle = PeriodStyles.NumPoints,
                Period = 20,
                PeriodAlign = PeriodAligns.Last
            };
            //ReLoadData();
        }

        private void LoadData()
        {
            if (tChart1.Chart.Series.Count > 0)
            {
                return;
            }

            tChart1.Legend.Alignment = Steema.TeeChart.LegendAlignments.Bottom;
            Series line = new Line();
            tChart1.Chart.Series.Add(line);

            for (int i = 0; i < 1000; i++)
            {
                line.Add(i, i);
            }

            Line functionLine = new Line
            {
                Title = $"Average",
                DataSource = new object[] { line },
                Function = new Average
                {
                    PeriodStyle = PeriodStyles.NumPoints,
                    Period = 20,
                    PeriodAlign = PeriodAligns.Last
                }
            };
            tChart1.Chart.Series.Add(functionLine);
        }

        private void ReLoadData()
        {
            for (int i = 0; i < 1000; i++)
            {
                tChart1.Chart.Series[0].Add(i, i);
            }
            tChart1.Chart.Series[1].Function.Recalculate();
        }

        private async void BtnExport_Click(object sender, EventArgs e)
        {
            var filePath = $"{_projectPath}\\Chart2.json";
            tChart1.Export.Template.IncludeData = true;
            await tChart1.Export.Template.SaveAsync(filePath);

            tChart1.Clear();

            Repaint();
        }

        private void BtnAddSampleData_Click(object sender, EventArgs e)
        {
            if (tChart1.Chart.Series.Count == 0)
            {
                LoadData();
            }

            tChart1.Series[0].Add(140);
            tChart1.Series[0].Add(170);
            tChart1.Series[0].Add(120);
            tChart1.Series[0].Add(180);
            tChart1.Series[0].Add(10);

            Repaint();
        }

        private void BtnCheckDatasourceFunction_Click(object sender, EventArgs e)
        {
            tChart1.Chart.Series[1].CheckDataSource();
            Repaint();
        }

        private void BtnShowEditor_Click(object sender, EventArgs e)
        {
            tChart1.ShowEditor();
            Repaint();
        }

        private async void BtnImport_Click(object sender, EventArgs e)
        {
            var filePath = $"{_projectPath}\\Chart2.json";
            if (File.Exists(filePath))
            {
                await tChart1.Import.Template.LoadAsync(filePath);
            }
            Repaint();
        }

        private void BtnClear_Click(object sender, EventArgs e)
        {
            tChart1.Clear();
            Repaint();
        }

        private void BtnLoadData_Click(object sender, EventArgs e)
        {
            LoadData();
            Repaint();
        }

        void Repaint()
        {
            tChart1.Invalidate();
            tChart1.Update();
            tChart1.Refresh();
        }
    }
}
